==> rabbitmq-server_3.7.18.orig.tar.xz: rabbitmq-server-3.7.18/deps/rabbit/README.md <==
# RabbitMQ Server

[RabbitMQ](https://rabbitmq.com) is a [feature rich](https://rabbitmq.com/documentation.html), multi-protocol messaging broker. It supports:

 * AMQP 0-9-1
 * AMQP 1.0
 * STOMP 1.0 through 1.2
 * MQTT 3.1.1


## Installation

 * [Installation guides](https://rabbitmq.com/download.html) for various platforms


## Tutorials & Documentation

 * [RabbitMQ tutorials](https://rabbitmq.com/getstarted.html)
 * [All documentation guides](https://rabbitmq.com/documentation.html)
 * [Documentation source](https://github.com/rabbitmq/rabbitmq-website/)
 * [Client libraries and tools](https://rabbitmq.com/devtools.html)
 * [Monitoring guide](https://rabbitmq.com/monitoring.html)
 * [Production checklist](https://rabbitmq.com/production-checklist.html)
 * [Runnable tutorials](https://github.com/rabbitmq/rabbitmq-tutorials/)

## Getting Help

 * [RabbitMQ mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users)
 * [Commercial support](https://rabbitmq.com/services.html) from [Pivotal](https://pivotal.io) for open source RabbitMQ
 * [Community Slack](https://rabbitmq-slack.herokuapp.com/)
 * `#rabbitmq` on Freenode


## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md) and our [development process overview](https://rabbitmq.com/github.html).

Questions about contributing, internals and so on are very welcome on the [mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users).


## Licensing

RabbitMQ server is [licensed under the MPL 1.1](LICENSE-MPL-RabbitMQ).


## Building From Source and Packaging

 * [Building RabbitMQ Server From Source](https://rabbitmq.com/build-server.html)
 * [Building RabbitMQ Server Packages](https://rabbitmq.com/build-server.html)


## Copyright

(c) Pivotal Software Inc., 2007-2018.

==> rabbitmq-server_3.8.2.orig.tar.xz: rabbitmq-server-3.8.2/deps/rabbit/README.md <==
# RabbitMQ Server

[RabbitMQ](https://rabbitmq.com) is a [feature rich](https://rabbitmq.com/documentation.html), multi-protocol messaging broker. It supports:

 * AMQP 0-9-1
 * AMQP 1.0
 * STOMP 1.0 through 1.2
 * MQTT 3.1.1


## Installation

 * [Installation guides](https://rabbitmq.com/download.html) for various platforms


## Tutorials & Documentation

 * [RabbitMQ tutorials](https://rabbitmq.com/getstarted.html)
 * [All documentation guides](https://rabbitmq.com/documentation.html)
 * [Documentation source](https://github.com/rabbitmq/rabbitmq-website/)
 * [Client libraries and tools](https://rabbitmq.com/devtools.html)
 * [Monitoring guide](https://rabbitmq.com/monitoring.html)
 * [Production checklist](https://rabbitmq.com/production-checklist.html)
 * [Runnable tutorials](https://github.com/rabbitmq/rabbitmq-tutorials/)


## Getting Help

 * [RabbitMQ mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users)
 * [Commercial support](https://rabbitmq.com/services.html) from [Pivotal](https://pivotal.io) for open source RabbitMQ
 * [Community Slack](https://rabbitmq-slack.herokuapp.com/)
 * `#rabbitmq` on Freenode


## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md) and our [development process overview](https://rabbitmq.com/github.html).

Questions about contributing, internals and so on are very welcome on the [mailing list](https://groups.google.com/forum/#!forum/rabbitmq-users).


## Licensing

RabbitMQ server is [licensed under the MPL 1.1](LICENSE-MPL-RabbitMQ).


## Building From Source and Packaging

 * [Building RabbitMQ from Source](https://rabbitmq.com/build-server.html)
 * [Building RabbitMQ Distribution Packages](https://rabbitmq.com/build-server.html)


## Copyright

(c) Pivotal Software Inc., 2007-2019.
